@@ -200,13 +200,8 @@ class Pipeline(ABC):
 
         #downloads files in pipeline, adds them to a temp file, adds file path to a list
         for item in curr_input_files:
-            download = self.seams.download_files( [ item["id"] ])
-            for item in download:
-                temp_file_full_path = os.path.join(tempfile.gettempdir(), item)
-                files.append(temp_file_full_path)
-                f = open(temp_file_full_path, "w", encoding="utf-8")
-                f.write(download[item])
-                f.close()
+            download = self.seams.download_file(item["id"])
+            files.append(download)
 
         return files
 
@@ -358,7 +353,7 @@ class Pipeline(ABC):
         """
         Wrapper method for logging warning severity messages
         """
-        self.log(Severity.WARNING, args, for_user=for_user, print_out=print_out)
+        self.log(Severity.WARNING, *args, for_user=for_user, print_out=print_out)
 
 
     def create_new_file(self, filename: str) -> tuple[str, str]:
@@ -402,7 +397,7 @@ class Pipeline(ABC):
         log_file.close()
 
         #uploads log file and attaches it as an edge to the pipeline run
-        log_file_upload = self.seams.upload_file("logs for {}".format(self.vertex_id), log_temp_file_full_path, file_type="File")
+        log_file_upload = self.seams.upload_file("logs for {}".format(self.vertex_id), log_temp_file_full_path, file_type="PipelineLogFile")
         self.seams.attach_edges(self.vertex_id, [ log_file_upload["id"] ])
 
         #creates new tempfile for user_logs
@@ -415,11 +410,18 @@ class Pipeline(ABC):
         user_log_file.close()
 
         #uploads user_log file and attaches it as an edge to the pipeline run
-        user_log_file_upload = self.seams.upload_file("user logs for {}".format(self.vertex_id), user_log_temp_file_full_path, file_type="File")
+        user_log_file_upload = self.seams.upload_file("user logs for {}".format(self.vertex_id), user_log_temp_file_full_path, file_type="PipelineLogFile")
         self.seams.attach_edges(self.vertex_id, [user_log_file_upload["id"]])
 
         return (log_file_upload["id"], user_log_file_upload["id"])
 
+    
+    def __check_int(self, value):
+        try:
+            return int(value)
+        except:
+            return value
+
 
     def __get_parameters(self) -> dict:
         '''
@@ -443,7 +445,7 @@ class Pipeline(ABC):
                 "Tenant Id required - do -h for help")
 
         # Set the default SEAMS schema
-        self.seams.set_current_schema_by_id(args.tenant_id)
+        self.seams.set_current_schema_by_id(self.__check_int(args.tenant_id))
 
         pipeline_run_vertex_id = ""
         if args.pipeline_name:
