@@ -1,11 +1,13 @@
 #!/usr/bin/env python
-from requests import Request, Session, utils
+from requests import Request, Session, utils, Response
 from itertools import islice
 import mimetypes
+import tempfile
 from seams.exceptions import SeamsException, SeamsAPIException
 import json
 import msal
 import os
+from requests_toolbelt import MultipartEncoder
 
 class Seams(object):
     '''
@@ -286,12 +288,12 @@ class Seams(object):
         response = None
         if not chunk_attributes:
             body = self.__properties_formatter(vertex_label, attributes)
-            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(vertex_id), content='application/json', data=body, schema_id=schema_id)
+            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(vertex_id), content_type='application/json', data=body, schema_id=schema_id)
 
         # Chunk the attributes
         for attributeChunk in self.__chunk_attributes(attributes, 10):
             body = self.__properties_formatter(vertex_label, attributeChunk)
-            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(vertex_id), content='application/json', data=body, schema_id=schema_id)
+            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(vertex_id), content_type='application/json', data=body, schema_id=schema_id)
 
         return response.json()
 
@@ -321,7 +323,7 @@ class Seams(object):
         if not chunk_attributes:
             # Create the vertex with no chunking
             body = self.__properties_formatter(vertex_label, attributes, vertex_name=vertex_name)
-            response = self.__seams_api_request('POST', '/vertex/create', content='application/json', data=body, schema_id=schema_id)
+            response = self.__seams_api_request('POST', '/vertex/create', content_type='application/json', data=body, schema_id=schema_id)
             return response.json()
 
         # Chunk the attributes
@@ -329,12 +331,12 @@ class Seams(object):
             body = self.__properties_formatter(vertex_label, {"name":vertex_name}, vertex_name=vertex_name)
 
         # Create the initial vertex
-        response = self.__seams_api_request('POST', '/vertex/create', content='application/json', data=body, schema_id=schema_id)
+        response = self.__seams_api_request('POST', '/vertex/create', content_type='application/json', data=body, schema_id=schema_id)
 
         # Chunk the properties as updates
         for attributeChunk in self.__chunk_attributes(attributes, 10):
             body = self.__properties_formatter(vertex_label, attributeChunk)
-            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(response.json()['id']), content='application/json', data=body, schema_id=schema_id)
+            response = self.__seams_api_request('PUT', '/vertex/update/{}'.format(response.json()['id']), content_type='application/json', data=body, schema_id=schema_id)
 
         return response.json()
 
@@ -524,21 +526,23 @@ class Seams(object):
         if not os.path.exists(filename):
             raise SeamsAPIException("File upload failed, file not found: {}".format(filename))
 
-        body = {'upload_preset': filename, 'fileType': file_type, 'caption': caption}
         mimetype = mimetypes.guess_type(filename)[0]
         if mimetype == "application/vnd.ms-excel":
             mimetype = "text/csv"
 
-        files = {'file': (filename, open(filename, 'rb'), mimetype)}
-        response = None
-        response = self.__seams_api_request('POST', '/upload/file', files=files, data=body, schema_id=schema_id)
+        encoder = MultipartEncoder(
+            fields={'file': (filename, open(filename, 'rb'), mimetype) , 'fileType': file_type , 'caption': caption }
+        )
+
+        response = self.__seams_api_request('POST', '/upload/file', data=encoder, content_type=encoder.content_type, schema_id=schema_id)
 
         return response.json()
 
 
     def download_file(self, 
                       vertex_id: str,
-                      schema_id: str = None) -> dict:
+                      schema_id: str = None,
+                      path: str = None) -> str:
         '''
         Download a single file
 
@@ -547,33 +551,27 @@ class Seams(object):
         :param schema_id:
             The id of the SEAMS schema to access  **OPTIONAL**
         :returns:
-            A dictionary where the key is the filename and the value is the file content
+            Path of the file downloaded
         '''
-
+        
         response = self.__seams_api_request('GET', '/download/file/{}'.format(vertex_id), schema_id=schema_id)
-        return { self.__file_name_formatter(response.headers['filename']): response.text }
+        file_path = self.__build_file_name(response, path)
+        with open(file_path, 'wb') as f:
+            for chunk in response.iter_content(chunk_size = 1024*1024):
+                if chunk:
+                    f.write(chunk)
+        return file_path
 
-
-    def download_files(self, 
-                       vertex_ids: list,
-                       schema_id: str = None) -> dict:
-        '''
-        Bulk download files
-
-        :param *files:
-            List of vertex id's the user would like to download  **REQUIRED**
-        :param schema_id:
-            The id of the SEAMS schema to access  **OPTIONAL**
-        :returns:
-            A dictionary where the key is the filename and the value is the file contents
-        '''
-
-        download_list = {}
-        for vertex_id in vertex_ids:
-            response = self.__seams_api_request('GET', '/download/file/{}'.format(vertex_id), schema_id=schema_id)
-            download_list[self.__file_name_formatter(response.headers['filename'])] = response.text
-
-        return download_list
+    
+    def __build_file_name(self,
+                          response: Response,
+                          path: str = None):
+        file_path = ""
+        if path:
+            file_path = os.path.join(path, self.__file_name_formatter(response.headers['filename']))
+        else:
+            file_path = os.path.join(tempfile.gettempdir(), self.__file_name_formatter(response.headers['filename']))
+        return file_path
 
 
     def __file_name_formatter(self, 
@@ -614,7 +612,7 @@ class Seams(object):
                        req_type: str, 
                        url:str, 
                        data: dict = None, 
-                       content:dict = None, 
+                       content_type :str = None, 
                        files = None,
                        json = None,
                        schema_id:str = None,
@@ -625,10 +623,12 @@ class Seams(object):
         
         bearer = self.aquire_token()
         header = {'Authorization': 'Bearer {}'.format(bearer)}
-        if content:
-            header['Content-Type'] = content
+        if content_type:
+            header['Content-Type'] = content_type
+
         session = Session()
 
+        # Get the full URL path
         if schema_api_url:
             if schema_id is None:
                 schema_id = self.get_current_schema_id()
@@ -638,7 +638,6 @@ class Seams(object):
         else:
             api_url = '{}{}'.format(self.URL, url)
 
-
         request = Request(req_type, api_url, headers=header, data=data, files=files, json=json)
         prepared = session.prepare_request(request)
         response = session.send(prepared)
